@@ -20,27 +20,27 @@ def format_es_param_result(r, param_list, is_need_decrypt, is_need_es_score, rou
     result_dict = {}
     format_company_id_en(r["_source"], route_key)
     if param_list and r["_source"]:
-        for key in param_list:
+        for param_key in param_list:
             value = r["_source"]
-            key_list = key.split(".")
-            for key in key_list:
+            key_arr = param_key.split(".")
+            for _key in key_arr:
                 if isinstance(value, list):
                     if value:
                         result = []
                         for v in value:
-                            if isinstance(v.get(key, None), list):
-                                result = result + v[key]
+                            if isinstance(v.get(_key, None), list):
+                                result = result + v[_key]
                             else:
-                                result.append(v.get(key, None))
+                                result.append(v.get(_key, None))
                         value = result
                 elif isinstance(value, dict):
                     if value:
-                        value = value.get(key, None)
+                        value = value.get(_key, None)
                 else:
                     pass
-            if result_dict.get(key) is None:
+            if result_dict.get(param_key) is None:
                 if value is not None:
-                    result_dict[key] = value
+                    result_dict[param_key] = value
     else:
         result_dict = r["_source"]
     if is_need_decrypt:
